@@ -112,36 +112,40 @@ getShrtlbls <- function(object){
 
 #' Simulate example data for pffr
 #' 
-#' Simulates example data for \code{\link{pffr}}.
-#' Scenario "all" generates data from a complex multivariate model 
-#' \eqn{Y_i(t) = \mu(t) + \int X_{1i}(s)\beta_1(s,t)ds + 
-#' \int X_{2i}(s)\beta_2(s,t)ds + xlin \beta_3(t) + 
-#' f(xte1, xte2) + f(xsmoo, t) + \beta_4 xconst + \epsilon_i(t)}.
-#' Scenarios "int", "ff", "te", "smoo", "lin", "const" generate data from 
-#' simpler models
-#' containing only the respective term(s)  in the model equation given above.
-#' Specifiying a vector-valued scenario will generate data from a 
-#' combination of the respective terms.
-#' See source code for details.\cr
-#' Sparse/irregular response trajectories can be generated by setting \code{propmissing} to something greater 
-#' than 0 (and smaller than 1). The return object then also includes a \code{ydata}-item
-#' with the sparsified data.
+#' Simulates example data for \code{\link{pffr}} from a variety of terms. 
+#' Scenario "all" generates data from a complex multivariate model \deqn{Y_i(t)
+#' = \mu(t) + \int X_{1i}(s)\beta_1(s,t)ds + xlin \beta_3(t) + f(xte1, xte2) +
+#' f(xsmoo, t) + \beta_4 xconst + \epsilon_i(t)}. Scenarios "int", "ff", "lin",
+#' "te", "smoo", "const" generate data from simpler models containing only the
+#' respective term(s)  in the model equation given above. Specifiying a
+#' vector-valued scenario will generate data from a combination of the
+#' respective terms. Sparse/irregular response trajectories can be generated by
+#' setting \code{propmissing} to something greater than 0 (and smaller than 1).
+#' The return object then also includes a \code{ydata}-item with the sparsified 
+#' data.
 #' 
-#' @param scenario see description
+#' See source code for details.\cr
+#' 
+#' @param scenario see Description
 #' @param n number of observations
-#' @param nxgrid number of evaluation points of functional covariates  
+#' @param nxgrid number of evaluation points of functional covariates
 #' @param nygrid number of evaluation points of the functional response
-#' @param SNR the signal-to-noise ratio for the generated data:  
-#'  empirical variance of the additive predictor divided by variance of the errors.
-#' @param propmissing proportion of missing data in the response, default = 0. See Details.
-#' @return a named list with the simulated data, and the true components of the predictor etc as attributes.  
+#' @param SNR the signal-to-noise ratio for the generated data: empirical
+#'   variance of the additive predictor divided by variance of the errors.
+#' @param propmissing proportion of missing data in the response, default = 0.
+#'   See Details.
+#' @param limits a function that defines an integration range, see
+#'   \code{\link{ff}}
+#' @return a named list with the simulated data, and the true components of the
+#'   predictor etc as attributes.
 pffrSim <- function(
         scenario="all",
         n = 100,
         nxgrid = 40,
         nygrid = 60,
         SNR = 10,
-        propmissing=0){
+        propmissing=0,
+        limits = NULL){
     
    mc <- match.call()
    for(i in 2:length(mc)) if(is.symbol(mc[[i]])) 
@@ -166,12 +170,12 @@ pffrSim <- function(
     test1 <- function(s, t){
       s*cos(pi*abs(s-t)) - .19
     }
-    test2 <- function(s, t, ss=0.3, st=0.4)
-    { 
-      cos(pi*s)*sin(pi*t) + (s*t)^2 - 0.11
-    }
-    s <- seq(0, 1, length=nxgrid)
-    t <- seq(0, 1, length=nygrid)
+#     test2 <- function(s, t, ss=0.3, st=0.4)
+#     { 
+#       cos(pi*s)*sin(pi*t) + (s*t)^2 - 0.11
+#     }
+     s <- seq(0, 1, length=nxgrid)
+     t <- seq(0, 1, length=nygrid)
     
     
     mu.t <- matrix(1 + dbeta(t, 2,7), nrow=n, ncol=nygrid, byrow=TRUE)
@@ -186,12 +190,16 @@ pffrSim <- function(
     L <- matrix(1/nxgrid, ncol=nxgrid, nrow=n)
     LX1 <- L*data$X1 
     beta1.st <- outer(s, t, test1)
+    if(!is.null(limits)){
+       range <- outer(s, t, limits)
+       beta1.st  <- beta1.st * range
+    }
     etaTerms$X1 <- LX1%*%beta1.st
     
-    data$X2 <- I(t(replicate(n, rf(s))))
-    LX2 <- L*data$X2 
-    beta2.st <- outer(s, t, test2)
-    etaTerms$X2 <- LX2%*%beta2.st
+#     data$X2 <- I(t(replicate(n, rf(s))))
+#     LX2 <- L*data$X2 
+#     beta2.st <- outer(s, t, test2)
+#     etaTerms$X2 <- LX2%*%beta2.st
     
     #scalar covariates
     data$xlin <- I(rnorm(n))
@@ -216,7 +224,7 @@ pffrSim <- function(
       eta <- mu.t + switch(scenario,
                            "int" = 0,
                            "all" = Reduce("+", etaTerms),
-                           "ff" =  etaTerms$X1 + etaTerms$X2,
+                           "ff" =  etaTerms$X1, #+ etaTerms$X2,
                            "lin" = etaTerms$xlin,
                            "smoo" = etaTerms$xsmoo,
                            "te" = etaTerms$xte,
@@ -225,7 +233,7 @@ pffrSim <- function(
       stopifnot(all(scenario %in% c("int" ,"ff", "lin", "smoo", "te", "const")))
       eta <- 0*mu.t
       if("int" %in% scenario) eta <- eta + mu.t
-      if("ff" %in% scenario) eta <- eta + etaTerms$X1 + etaTerms$X2
+      if("ff" %in% scenario) eta <- eta + etaTerms$X1 #+ etaTerms$X2
       if("lin" %in% scenario) eta <- eta + etaTerms$xlin
       if("smoo" %in% scenario) eta <- eta + etaTerms$xsmoo
       if("te" %in% scenario) eta <- eta + etaTerms$xte
@@ -233,7 +241,8 @@ pffrSim <- function(
     }
     
     
-    eps <-  sd(as.vector(eta))/sqrt(SNR) * matrix(scale(rnorm(n*nygrid)), nrow=n)
+    eps <-  sd(as.vector(eta))/sqrt(SNR) * matrix(scale(rnorm(n*nygrid)), 
+                                                  nrow=n)
     data$Y <- I(eta + eps)
     
     
@@ -247,7 +256,7 @@ pffrSim <- function(
       data <- as.data.frame(data, rownames=1:n)
                  
       ydata <- data.frame(.obs = rep(1:n, each=nygrid)[!missing],
-                          .index = rep(1:nygrid, times=n)[!missing],
+                          .index = rep(t, times=n)[!missing],
                           .value = as.vector(t(data$Y))[!missing])
       
       return(structure(list(data=data, ydata=ydata), xindex=s, yindex=t, 
@@ -269,7 +278,8 @@ pffrSim <- function(
 #' The basic idea is to replace the k-th zero eigenvalue of the original penalty by 
 #' \eqn{s^k \nu_m}, where \eqn{s} is the shrinkage factor (defaults to 0.1)
 #' and \eqn{\nu_m} is the smallest non-zero eigenvalue. See reference for the
-#' original idea, implentation follows that in the 'ts' and 'cs' constructors.
+#' original idea, implementation follows that in the 'ts' and 'cs' constructors
+#' (see \code{\link[mgcv]{smooth.terms}}).
 #' 
 #' @param object see \code{\link[mgcv]{smooth.construct}}. The shrinkage factor can be speficied via \code{object$xt$shrink}
 #' @param data see \code{\link[mgcv]{smooth.construct}}.
